ApiClient class

Main API client for ScanPro

Constructors

ApiClient()
Constructor

Properties

conversion → ConversionApi
Endpoints
latefinal
hashCode → int
The hash code for this object.
no setterinherited
ocr → OcrApi
latefinal
pdfTools → PdfToolsApi
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
security → SecurityApi
latefinal

Methods

get(String endpoint, {Map<String, String>? params}) → Future<ApiResponse>
Make a GET request
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String endpoint, {Map<String, dynamic>? body, Map<String, String>? params}) → Future<ApiResponse>
Make a POST request with JSON body
toString() → String
A string representation of this object.
inherited
uploadFile(String endpoint, String fieldName, File file, {Map<String, String>? fields, String? fileNameField}) → Future<ApiResponse>
Make a POST request with file upload

Operators

operator ==(Object other) → bool
The equality operator.
inherited