ConversionFormat enum

Supported input and output formats for conversion

Inheritance
Available extensions

Values

pdf → const ConversionFormat

PDF format

docx → const ConversionFormat

Word document format

xlsx → const ConversionFormat

Excel spreadsheet format

pptx → const ConversionFormat

PowerPoint presentation format

jpg → const ConversionFormat

JPEG image format

png → const ConversionFormat

PNG image format

html → const ConversionFormat

HTML format

Properties

extension → String

Available on ConversionFormat, provided by the ConversionFormatExtension extension

Get the file extension for this format
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
mimeType → String

Available on ConversionFormat, provided by the ConversionFormatExtension extension

Get the MIME type for this format
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ConversionFormat>
A constant List of the values in this enum, in order of their declaration.