PageRotation class

Page rotation information for PDF rotation

Constructors

PageRotation({required int pageNumber, required RotationAngle angle, int original = 0})
Constructor

Properties

angle → RotationAngle
Rotation angle
final
hashCode → int
The hash code for this object.
no setterinherited
original → int
Original angle before rotation
final
pageNumber → int
Page number (1-based)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert to a Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited