PdfToolsApi class

API endpoints for PDF tools

Inheritance

Constructors

PdfToolsApi(ApiClient client)
Constructor

Properties

client → ApiClient
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addImageWatermark(File file, File watermarkImage, ImageWatermarkOptions options) → Future<ApiResponse>
Add an image watermark to a PDF
addTextWatermark(File file, TextWatermarkOptions options) → Future<ApiResponse>
Add a text watermark to a PDF
compressPdf(File file, {CompressionQuality quality = CompressionQuality.medium}) → Future<ApiResponse>
Compress a PDF file
getPdfInfo(File file) → Future<ApiResponse>
Get PDF information
mergePdfs(List<File> files, {MergeOptions? options}) → Future<ApiResponse>
Merge multiple PDF files
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
repairPdf(File file, {RepairOptions? options}) → Future<ApiResponse>
Repair a PDF file
rotatePdf(File file, List<PageRotation> rotations) → Future<ApiResponse>
Rotate PDF pages
splitPdf(File file, {required SplitOptions options}) → Future<ApiResponse>
Split a PDF file
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited