PermissionOptions class

Permission options for PDF protection

Constructors

PermissionOptions({String permission = 'restricted', bool allowPrinting = false, bool allowCopying = false, bool allowEditing = false})
Constructor
const
PermissionOptions.allowAll()
Allow all permissions
const

Properties

allowCopying → bool
Allow copying text and images
final
allowEditing → bool
Allow editing and annotations
final
allowPrinting → bool
Allow printing
final
hashCode → int
The hash code for this object.
no setterinherited
permission → String
Permission mode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toParams() → Map<String, String>
Convert to API parameters
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited