ProtectPdfOptions class

PDF protection options

Inheritance

Constructors

ProtectPdfOptions({required String password, String? ownerPassword, String permission = 'restricted', String encryptionLevel = '256', bool allowPrinting = false, bool allowCopying = false, bool allowEditing = false})
Constructor
const
ProtectPdfOptions.withAllPermissions({required String password, String? ownerPassword, String encryptionLevel = '256'})
Create protection options with all permissions allowed
factory

Properties

allowCopying → bool
Allow copying content
final
allowEditing → bool
Allow editing
final
allowPrinting → bool
Allow printing
final
encryptionLevel → String
Encryption level (40, 128, or 256 bits)
final
hashCode → int
The hash code for this object.
no setterinherited
ownerPassword → String?
Owner password (for setting permissions)
final
password → String
The password for unlocking or protecting the PDF
finalinherited
permission → String
Permission level (restricted or all)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toParams() → Map<String, String>
Convert to API parameters
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited