ProtectionOptions class

Password protection options for PDF

Constructors

ProtectionOptions({required String password, String? ownerPassword, String encryptionLevel = '256', PermissionOptions permissions = const PermissionOptions()})
Constructor

Properties

encryptionLevel → String
Encryption level (40, 128, or 256)
final
hashCode → int
The hash code for this object.
no setterinherited
ownerPassword → String?
Owner password (required to change permissions)
final
password → String
User password (required to open the document)
final
permissions → PermissionOptions
Permission settings
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toParams() → Map<String, String>
Convert to API parameters
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited