RepairOptions class

PDF repair options

Constructors

RepairOptions({RepairMode mode = RepairMode.standard, bool preserveFormFields = true, bool preserveAnnotations = true, bool preserveBookmarks = true, bool optimizeImages = false, String? password})
Constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
mode → RepairMode
Repair mode
final
optimizeImages → bool
Optimize images
final
password → String?
PDF password (if the PDF is password-protected)
final
preserveAnnotations → bool
Preserve annotations
final
preserveBookmarks → bool
Preserve bookmarks
final
preserveFormFields → bool
Preserve form fields
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toParams() → Map<String, String>
Convert to API parameters
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited