SignPageData class

Page data for PDF signing

Constructors

SignPageData({required double width, required double height, required double originalWidth, required double originalHeight})
Constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
Height of the page
final
originalHeight → double
Original height of the page
final
originalWidth → double
Original width of the page
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
Width of the page
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert to JSON
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited