SignPdfElement class

Options for signing a PDF

Constructors

SignPdfElement({required String type, required String data, required Map<String, double> position, required Map<String, double> size, double rotation = 0, double scale = 1, required int page, String? color, double? fontSize, String? fontFamily})
Constructor
SignPdfElement.drawing({required String drawingData, required double x, required double y, required double width, required double height, double rotation = 0, double scale = 1, required int page})
Create a drawing element
factory
SignPdfElement.image({required String imageData, required double x, required double y, required double width, required double height, double rotation = 0, double scale = 1, required int page})
Create an image element
factory
SignPdfElement.signature({required String signatureData, required double x, required double y, required double width, required double height, double rotation = 0, double scale = 1, required int page})
Create a signature element
factory
SignPdfElement.stamp({required String stampData, required double x, required double y, required double width, required double height, double rotation = 0, double scale = 1, required int page})
Create a stamp element
factory
SignPdfElement.text({required String text, required double x, required double y, required double width, required double height, double rotation = 0, double scale = 1, required int page, String color = '#000000', double fontSize = 12, String fontFamily = 'Arial'})
Create a text element
factory

Properties

color → String?
Text color (for text elements)
final
data → String
Element data
final
fontFamily → String?
Font family (for text elements)
final
fontSize → double?
Font size (for text elements)
final
hashCode → int
The hash code for this object.
no setterinherited
page → int
Page number
final
position → Map<String, double>
Position (x, y)
final
rotation → double
Rotation angle
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
Scale factor
final
size → Map<String, double>
Size (width, height)
final
type → String
Element type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert to JSON
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited