SplitOptions class

PDF split options

Constructors

SplitOptions({SplitMethod method = SplitMethod.byRange, String? pageRanges, int? pagesPerFile})
Constructor

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → SplitMethod
Split method
final
pageRanges → String?
Page ranges (only used when method is byRange)
final
pagesPerFile → int?
Number of pages per file (only used when method is everyNPages)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toParams() → Map<String, String>
Convert to API parameters
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited