TextWatermarkOptions class

Text watermark options

Inheritance

Constructors

TextWatermarkOptions({required String text, String textColor = '#FF0000', int fontSize = 48, String fontFamily = 'Arial', WatermarkPosition position = WatermarkPosition.center, PageRange pages = const PageRange.allPages(), int opacity = 30, int rotation = 45, int? customX, int? customY})
Constructor

Properties

customX → int?
Custom X position (percentage, 0-100, only used when position is custom)
finalinherited
customY → int?
Custom Y position (percentage, 0-100, only used when position is custom)
finalinherited
fontFamily → String
Font family
final
fontSize → int
Font size
final
hashCode → int
The hash code for this object.
no setterinherited
opacity → int
Opacity of the watermark (0-100)
finalinherited
pages → PageRange
Page range to apply the watermark to
finalinherited
position → WatermarkPosition
Position of the watermark
finalinherited
rotation → int
Rotation angle for the watermark (0-360)
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Text to use as watermark
final
textColor → String
Text color (hex format, e.g., "#FF0000")
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toParams() → Map<String, String>
Convert to API parameters
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited