WatermarkOptions class

Watermark options

Implementers

Constructors

WatermarkOptions({WatermarkPosition position = WatermarkPosition.center, PageRange pages = const PageRange.allPages(), int opacity = 30, int rotation = 45, int? customX, int? customY})
Constructor

Properties

customX → int?
Custom X position (percentage, 0-100, only used when position is custom)
final
customY → int?
Custom Y position (percentage, 0-100, only used when position is custom)
final
hashCode → int
The hash code for this object.
no setterinherited
opacity → int
Opacity of the watermark (0-100)
final
pages → PageRange
Page range to apply the watermark to
final
position → WatermarkPosition
Position of the watermark
final
rotation → int
Rotation angle for the watermark (0-360)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toParams() → Map<String, String>
Convert to API parameters
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited